## Unpublished

- Shows only 20 records in ppt_all, apt_all, and que_all, and who total number of each record type in their corresponding page #51
- Change nav bar, nav pills, and card header fonts to Noto Sans Display
- Add Help section with links to GitHub issues
- Simplify README instructions


## v0.1.4

- Add record-deleting functions to API
- Calendar events using the Python API #43
- Fix PyPi URLs #40
- Allow 0m0d age #44
- Delete events/appointments/emails after testing #46
- Add dev scripts for convenience during test development
- Fixes table width
- Appointment ID table has wrong width #41

## v0.1.3

- Minor fixes

## v0.1.2

- Fixes participant table position (#36)
- Updates README file
- Fixes questionnaire ID page (#38)
- Removes Dockerfile
- Renames studies to new standard

## v0.1.1

- Make command for updating CHANGELOG
- Simplify utils
- Add testing for `api.send_email` locally
- Add client testing for emails

## v0.1.0

- Restructure the routes into modules.
- Add pytest suite to API, utils, and main routes in the app.
- Add coverage analysis to pytest routines.
- Add coverage report to GitHub workflows.
- Add circle plot for appointment status.


